# Table of Contents

- [automation-examples-automations-with-webhooks](<./automation-examples-automations-with-webhooks.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Automations Best Practices: Automations with Webhooks](<./Automations-Best-Practices-Automations-with-Webhooks.md>)
  - [Overview](<./Automations-Best-Practices-Automations-with-Webhooks/Overview.md>)
  - [Best Practices](<./Automations-Best-Practices-Automations-with-Webhooks/Best-Practices.md>)
  - [Sending Notifications on Quality State Changes](<./Automations-Best-Practices-Automations-with-Webhooks/Sending-Notifications-on-Quality-State-Changes.md>)
  - [Initiating a Survey Run when a Tag is Added](<./Automations-Best-Practices-Automations-with-Webhooks/Initiating-a-Survey-Run-when-a-Tag-is-Added.md>)
  - [Initiating Calculations on Lifecycle Phase Changes](<./Automations-Best-Practices-Automations-with-Webhooks/Initiating-Calculations-on-Lifecycle-Phase-Changes.md>)
  - [Initiating Calculations on Field Changes](<./Automations-Best-Practices-Automations-with-Webhooks/Initiating-Calculations-on-Field-Changes.md>)
